@@ -1,6 +1,6 @@
 package Git::Hooks;
 # ABSTRACT: Framework for implementing Git (and Gerrit) hooks
-$Git::Hooks::VERSION = '2.1.3';
+$Git::Hooks::VERSION = '2.1.4';
 use 5.010;
 use strict;
 use warnings;
@@ -107,7 +107,7 @@ Git::Hooks - Framework for implementing Git (and Gerrit) hooks
 
 =head1 VERSION
 
-version 2.1.3
+version 2.1.4
 
 =head1 SYNOPSIS
 
@@ -141,11 +141,20 @@ options. (More on this later.)
 
 =head1 INTRODUCTION
 
+=over
+
 "Git is a fast, scalable, distributed revision control system with an
 unusually rich command set that provides both high-level operations
 and full access to
 internals. (L<Git README|https://github.com/gitster/git#readme>)"
 
+=back
+
+If you already know about L<Git|http://git-scm.org/> and hooks and simply
+want to get on with business go straight to our
+L<wiki|https://github.com/gnustavo/Git-Hooks/wiki> and read the relevant
+tutorials.
+
 In order to really understand what this is all about you need to
 understand L<Git|http://git-scm.org/> and its hooks. You can read
 everything about this in the
@@ -1213,6 +1222,10 @@ though.
 
 =over
 
+=item * L<Git::Hooks wiki|https://github.com/gnustavo/Git-Hooks/wiki>
+
+Tutorials for Git users and administrators.
+
 =item * L<Git::Repository>
 
 Perl interface to Git repositories.
