@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckWhitespace;
 # ABSTRACT: Git::Hooks plugin for checking whitespace errors
-$Git::Hooks::CheckWhitespace::VERSION = '2.1.3';
+$Git::Hooks::CheckWhitespace::VERSION = '2.1.4';
 use 5.010;
 use utf8;
 use strict;
@@ -28,10 +28,10 @@ sub check_affected_refs {
             $old_commit eq $git->undef_commit ? $git->empty_tree : $old_commit,
             $new_commit,
         );
-        my $stderr = do { local $/ = undef; readline($cmd->stderr)};
+        my $output = do { local $/ = undef; readline($cmd->stdout)};
         $cmd->close;
         if ($cmd->exit() != 0) {
-            $git->error($PKG, "whitespace errors in the changed files in $ref", $stderr);
+            $git->error($PKG, "whitespace errors in the changed files in $ref", $output);
             ++$errors;
         };
     }
@@ -43,12 +43,12 @@ sub check_commit {
     my ($git) = @_;
 
     my $cmd = $git->command(qw/diff-index --check --cached/, $git->get_head_or_empty_tree());
-    my $stderr = do { local $/ = undef; readline($cmd->stderr)};
+    my $output = do { local $/ = undef; readline($cmd->stdout)};
     $cmd->close;
     if ($cmd->exit() == 0) {
         return 1;
     } else {
-        $git->error($PKG, 'whitespace errors in the changed files', $stderr);
+        $git->error($PKG, 'whitespace errors in the changed files', $output);
         return 0;
     };
 }
@@ -59,12 +59,12 @@ sub check_patchset {
     return 1 if $git->im_admin();
 
     my $cmd = $git->command(qw/diff-tree -r -m --check/, $opts->{'--commit'});
-    my $stderr = do { local $/ = undef; readline($cmd->stderr)};
+    my $output = do { local $/ = undef; readline($cmd->stdout)};
     $cmd->close;
     if ($cmd->exit() == 0) {
         return 1;
     } else {
-        $git->error($PKG, 'whitespace errors in the changed files', $stderr);
+        $git->error($PKG, 'whitespace errors in the changed files', $output);
         return 0;
     };
 }
@@ -91,7 +91,7 @@ Git::Hooks::CheckWhitespace - Git::Hooks plugin for checking whitespace errors
 
 =head1 VERSION
 
-version 2.1.3
+version 2.1.4
 
 =head1 DESCRIPTION
 
